pub struct GithubAppAuth { /* private fields */ }Implementations
Sourceimpl GithubAppAuth
impl GithubAppAuth
Sourcepub async fn authenticate(
app_id: String,
installation_id: String,
key: SecretValue,
) -> Result<Self>
pub async fn authenticate( app_id: String, installation_id: String, key: SecretValue, ) -> Result<Self>
Create a new GitHub App auth handle and fetch the initial installation token.
Sourcepub async fn get_or_refresh(&mut self) -> Result<String>
pub async fn get_or_refresh(&mut self) -> Result<String>
Return a valid installation token, refreshing if the cached one is stale.